/* pcap2rumint.c                                         */
/* written by Greg Conti, April 2005                     */
/* www.rumint.org                                        */
/* copyright 2005                                        */
/*                                                       */
/* This program converts pcap to rumint files.  First,   */
/* it opens the pcap file and extracts the raw data from */
/* each packet.  It then writes then data to a second    */
/* rumint formatted file.                                */
/*                                                       */
/* The file format is structured as follows:             */
/*   <RUMINT>                                            */
/*     raw packet data 1 <RUMINT[CR][LF]>                */
/*     raw packet data 2 <RUMINT[CR][LF]>                */
/*     ...                                               */
/*     raw packet data N <RUMINT[CR][LF]>                */
/*   <RUMINT[EOF]>                                       */
/*                                                       */
/*  Notes:  While this file format works under most      */
/*  circumstances it will fail (badly) if the network    */
/*  traffic, by chance or by design, contains the flags  */
/*  used in the file format described above.  This       */
/*  should be addressed in future versions of the file   */
/*  format.  A more elegant solution would prepend       */
/*  packet length before each packet.  An even better    */
/*  solution would be to open the pcap format natively.  */
/*  Perhaps in version 2.0 :)                            */
/*                                                       */                                             
/*  This program is distributed under the GNU Public     */
/*  License.  See:                                       */
/*    http://www.gnu.org/copyleft/gpl.html               */
/*  for more information.                                */ 
/*                                                       */
/*  usage:  rumint2pcap pcap_source_file rumint_outfile  */
  
   

#include <stdio.h>
#include <pcap.h>

  pcap_t *inhandle;                /* pcap file handle        */
  FILE *outhandle;                 /* output file handle      */
  struct pcap_pkthdr header;       /* pcap header struct      */
  char errbuf[PCAP_ERRBUF_SIZE];   /* pcap error buffer       */
  const u_char *packet;            /* The actual packet       */
  int moreleft = 1;                /* end of file flag        */
  int counter = 0;                 /* byte counter per packet */
  long packetcounter = 0;          /* holds number of packets */


int main(int argc, char* argv[])
{

  /* simple error checking for correct usage */
  if (argc!=3) {
    printf ("\nusage: rumint2pcap inputfile outputfile\n");
    printf ("  -inputfile is a packet capture file in pcap format\n");
    printf ("  -outputfile is a packet capture file in rumint format\n\n");
    return -1;
  }
  

  printf("\nconverting pcap file \"%s\" to rumint file \"%s\"\n", argv[1], argv[2]);

  /* open pcap file */
  if ((inhandle = pcap_open_offline(argv[1], errbuf)) == NULL){
    fprintf(stderr,"\nError opening pcap file\n");
    return -1;
  }

  /* open rumint file */
  if ((outhandle = fopen(argv[2],"w")) == NULL){
    fprintf(stderr,"\nError opening rumint file\n");
    return -1;
  }
  
  fputs("<RUMINT>",outhandle);  /* beginning of file marker */
  do {
  	packet = pcap_next(inhandle, &header);	
  	if (packet) {
         packetcounter++; /* overflow is not critical to program function */

         /* process each byte of packet */
         for (counter=0; counter<header.len; counter++) {
           fputc(packet[counter],outhandle);
         }
         
         fputs("<RUMINT[CR][LF]>",outhandle); /* end of packet marker */
        } else	  
  	{ 
          moreleft = 0;
        }
  } while (moreleft);
  
  fputs("<RUMINT[EOF]>",outhandle); /* end of file marker */
  pcap_close(inhandle);
  fclose(outhandle);
  printf("%d packets converted...\n\n", packetcounter);

  return(0);  
}

  
  



